# @push.rocks/smartlog-destination-devtools
beautiful logging for the browser

## Install
To install `@push.rocks/smartlog-destination-devtools`, use the following command in your project:

```sh
npm install @push.rocks/smartlog-destination-devtools --save
```

This will add `smartlog-destination-devtools` as a dependency to your project and you can start using it to enhance your logging in the browser.

## Usage

`@push.rocks/smartlog-destination-devtools` provides a seamless way to output beautified log messages directly to your browser's console, making use of the `@push.rocks/smartlog` ecosystem for structured and meaningful logging.

### Getting Started

First, ensure you have `@push.rocks/smartlog` installed in your project. If not, install it alongside `smartlog-destination-devtools`:

```sh
npm install @push.rocks/smartlog @push.rocks/smartlog-destination-devtools --save
```

Now, let's set up the basic usage of `smartlog-destination-devtools` within a TypeScript project.

### Initialization

Import the required modules and initialize `Smartlog` and `SmartlogDestinationDevtools`.

```typescript
import { Smartlog, ISmartlogOptions, ILogContext } from '@push.rocks/smartlog';
import { SmartlogDestinationDevtools } from '@push.rocks/smartlog-destination-devtools';

// Define your log context
const logContext: ILogContext = {
  company: 'Your Company',
  companyunit: 'Your Company Unit',
  containerName: 'YourContainerName',
  environment: 'development',
  runtime: 'browser',
  zone: 'frontend',
};

// Set up Smartlog options
const smartlogOptions: ISmartlogOptions = {
  minimumLogLevel: 'info',
  logContext: logContext,
};

// Initialize Smartlog with options
const smartlogInstance = new Smartlog(smartlogOptions);

// Initialize the DevTools destination
const devtoolsDestination = new SmartlogDestinationDevtools();

// Add the DevTools destination to Smartlog
smartlogInstance.addDestination(devtoolsDestination);
```

### Logging

Now that setup is complete, you can start logging messages. `@push.rocks/smartlog` uses a structured format for logs, which `@push.rocks/smartlog-destination-devtools` will beautifully display in the console.

```typescript
// Log an information message
smartlogInstance.info('This is an informational message', { optional: 'additional data' });

// Log a warning
smartlogInstance.warn('This is a warning message', { check: 'some warning data' });

// Log an error
smartlogInstance.error('This is an error message', new Error('Something went wrong'));
```

### Customization

`SmartlogDestinationDevtools` class is designed to automatically handle log messages sent through `@push.rocks/smartlog` and print them to the browser's console in a visually structured and highlighted manner. Currently, it translates different log levels (`info`, `warn`, `error`, `note`, `success`) to different styles in the DevTools console.

Since the core feature of `smartlog-destination-devtools` is to enhance the visual feedback of logs in the development environment, further customization can be achieved by altering the source code of the `handleLog` method within the class to fit your styling needs or by extending the class with your own implementation.

### Advanced Usage

For more advanced scenarios like filtering logs or integrating with other logging systems, refer to the `@push.rocks/smartlog` documentation, as `smartlog-destination-devtools` acts as a destination for the logs managed by `@push.rocks/smartlog`.

---

By integrating `@push.rocks/smartlog-destination-devtools`, you're equipped to make your browser-based debugging and logging more effective and visually appealing, leveraging the structured logging capabilities of `@push.rocks/smartlog`.

## License and Legal Information

This repository contains open-source code that is licensed under the MIT License. A copy of the MIT License can be found in the [license](license) file within this repository. 

**Please note:** The MIT License does not grant permission to use the trade names, trademarks, service marks, or product names of the project, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

### Trademarks

This project is owned and maintained by Task Venture Capital GmbH. The names and logos associated with Task Venture Capital GmbH and any related products or services are trademarks of Task Venture Capital GmbH and are not included within the scope of the MIT license granted herein. Use of these trademarks must comply with Task Venture Capital GmbH's Trademark Guidelines, and any usage must be approved in writing by Task Venture Capital GmbH.

### Company Information

Task Venture Capital GmbH  
Registered at District court Bremen HRB 35230 HB, Germany

For any legal inquiries or if you require further information, please contact us via email at hello@task.vc.

By using this repository, you acknowledge that you have read this section, agree to comply with its terms, and understand that the licensing of the code does not imply endorsement by Task Venture Capital GmbH of any derivative works.
